@@ -296,13 +296,7 @@ QTextDocument* Converter::convert( const QString &fileName )
 
       QTextBlock before;
       if(firstPage) {
-        // preHtml & postHtml make it possible to have a margin around the content of the page
-        const QString preHtml = QString::fromLatin1("<html><head></head><body>"
-                                        "<table style=\"-qt-table-type: root; margin-top:%1px; margin-bottom:%1px; margin-left:%1px; margin-right:%1px;\">"
-                                        "<tr>"
-                                        "<td style=\"border: none;\">").arg(mTextDocument->padding);
-        const QString postHtml = QStringLiteral("</tr></table></body></html>");
-        mTextDocument->setHtml(preHtml + htmlContent + postHtml);
+        mTextDocument->setHtml(htmlContent);
         firstPage = false;
         before = mTextDocument->begin();
       } else {
@@ -313,10 +307,10 @@ QTextDocument* Converter::convert( const QString &fileName )
       qApp->setPalette(orig);
       // HACK END
 
-      QTextCursor csr(mTextDocument);   // a temporary cursor
-      csr.movePosition(QTextCursor::Start);
+      QTextCursor csr(before);   // a temporary cursor pointing at the begin of the last inserted block
       int index = 0;
-      while( !(csr = mTextDocument->find(QStringLiteral("<video></video>"),csr)).isNull() ) {
+
+      while( !movieAnnots.isEmpty() && !(csr = mTextDocument->find(QStringLiteral("<video></video>"),csr)).isNull() ) {
         const int posStart = csr.position();
         const QPoint startPoint = calculateXYPosition(mTextDocument, posStart);
         QImage img(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("okular/pics/okular-epub-movie.png")));
@@ -329,10 +323,10 @@ QTextDocument* Converter::convert( const QString &fileName )
         csr.movePosition(QTextCursor::NextWord);
       }
 
-      csr.movePosition(QTextCursor::Start);
+      csr = QTextCursor(before);
       index = 0;
       const QString keyToSearch(QStringLiteral("<audio></audio>"));
-      while( !(csr = mTextDocument->find(keyToSearch, csr)).isNull() ) {
+      while( !soundActions.isEmpty() && !(csr = mTextDocument->find(keyToSearch, csr)).isNull() ) {
         const int posStart = csr.position() - keyToSearch.size();
         const QImage img(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("okular/pics/okular-epub-sound-icon.png")));
         csr.insertImage(img);
