@@ -78,11 +78,16 @@
 // transition effect to the next frame
 struct PresentationFrame
 {
+    PresentationFrame() = default;
+
     ~PresentationFrame()
     {
         qDeleteAll( videoWidgets );
     }
 
+    PresentationFrame(const PresentationFrame &) = delete;
+    PresentationFrame &operator=(const PresentationFrame &) = delete;
+
     void recalcGeometry( int width, int height, float screenRatio )
     {
         // calculate frame geometry keeping constant aspect ratio
@@ -148,6 +153,7 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     m_ac( collection ), m_screenSelect( nullptr ), m_isSetup( false ), m_blockNotifications( false ), m_inBlackScreenMode( false ),
     m_showSummaryView( Okular::Settings::slidesShowSummary() ),
     m_advanceSlides( Okular::SettingsCore::slidesAdvance() ),
+    m_goToPreviousPageOnRelease( false ),
     m_goToNextPageOnRelease( false )
 {
     Q_UNUSED( parent )
@@ -167,7 +173,7 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     m_topBar = new PresentationToolBar( this );
     m_topBar->setObjectName( QStringLiteral( "presentationBar" ) );
     m_topBar->setMovable( false );
-    m_topBar->layout()->setMargin(0);
+    m_topBar->layout()->setContentsMargins(0, 0, 0, 0);
     m_topBar->addAction( QIcon::fromTheme( layoutDirection() == Qt::RightToLeft ? QStringLiteral("go-next") : QStringLiteral("go-previous") ), i18n( "Previous Page" ), this, SLOT(slotPrevPage()) );
     m_pagesEdit = new KLineEdit( m_topBar );
     QSizePolicy sp = m_pagesEdit->sizePolicy();
@@ -193,11 +199,6 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     setPlayPauseIcon();
     addAction( playPauseAct );
     m_topBar->addSeparator();
-    QAction *eraseDrawingAct = collection->action( QStringLiteral("presentation_erase_drawings") );
-    eraseDrawingAct->setEnabled( true );
-    connect(eraseDrawingAct, &QAction::triggered, this, &PresentationWidget::clearDrawings);
-    m_topBar->addAction( eraseDrawingAct );
-    addAction( eraseDrawingAct );
 
     foreach(QAction *action, drawingToolActions->actions())
     {
@@ -208,6 +209,12 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     connect( drawingToolActions, &DrawingToolActions::changeEngine, this, &PresentationWidget::slotChangeDrawingToolEngine );
     connect( drawingToolActions, &DrawingToolActions::actionsRecreated, this, &PresentationWidget::slotAddDrawingToolActions );
 
+    QAction *eraseDrawingAct = collection->action( QStringLiteral("presentation_erase_drawings") );
+    eraseDrawingAct->setEnabled( true );
+    connect(eraseDrawingAct, &QAction::triggered, this, &PresentationWidget::clearDrawings);
+    m_topBar->addAction( eraseDrawingAct );
+    addAction( eraseDrawingAct );
+
     QDesktopWidget *desktop = QApplication::desktop();
     if ( desktop->numScreens() > 1 )
     {
@@ -232,7 +239,7 @@ PresentationWidget::PresentationWidget( QWidget * parent, Okular::Document * doc
     // change topbar background color
     QPalette p = m_topBar->palette();
     p.setColor( QPalette::Active, QPalette::Button, Qt::gray );
-    p.setColor( QPalette::Active, QPalette::Background, Qt::darkGray );
+    p.setColor( QPalette::Active, QPalette::Window, Qt::darkGray );
     m_topBar->setPalette( p );
 
     // Grab swipe gestures to change pages
@@ -701,7 +708,39 @@ void PresentationWidget::mousePressEvent( QMouseEvent * e )
             return;
         }
 
-        m_goToNextPageOnRelease = true;
+        // Actual mouse press events always lead to the next page page
+        if ( e->source() == Qt::MouseEventNotSynthesized )
+        {
+            m_goToNextPageOnRelease = true;
+        }
+        // Touch events may lead to the previous or next page
+        else if ( Okular::Settings::slidesTapNavigation() != Okular::Settings::EnumSlidesTapNavigation::Disabled )
+        {
+            switch ( Okular::Settings::slidesTapNavigation() )
+            {
+                case Okular::Settings::EnumSlidesTapNavigation::ForwardBackward:
+                {
+                    if ( e->x() < ( geometry().width()/2 ) )
+                    {
+                        m_goToPreviousPageOnRelease = true;
+                    }
+                    else
+                    {
+                        m_goToNextPageOnRelease = true;
+                    }
+                    break;
+                }
+                case Okular::Settings::EnumSlidesTapNavigation::Forward:
+                {
+                    m_goToNextPageOnRelease = true;
+                    break;
+                }
+                case Okular::Settings::EnumSlidesTapNavigation::Disabled:
+                {
+                    // Do Nothing
+                }
+            }
+        }
     }
     // pressing the "move forward" mouse button: unlike the left button this
     // always means "show next page", so we unconditionally delegate to that
@@ -731,6 +770,11 @@ void PresentationWidget::mouseReleaseEvent( QMouseEvent * e )
         m_pressedLink = nullptr;
     }
 
+    if ( m_goToPreviousPageOnRelease ) {
+        slotPrevPage();
+        m_goToPreviousPageOnRelease = false;
+    }
+
     if ( m_goToNextPageOnRelease ) {
         slotNextPage();
         m_goToNextPageOnRelease = false;
@@ -805,7 +849,7 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
             generatePage();
     }
 
-    // check painting rect consistancy
+    // check painting rect consistency
     QRect r = pe->rect().intersected( QRect( QPoint( 0, 0 ), geometry().size() ) );
     if ( r.isNull() )
         return;
@@ -2104,7 +2148,7 @@ void PresentationWidget::initTransition( const Okular::PageTransition *transitio
                 int L = 0, T = 0, R = m_width, B = m_height;
                 for ( int i = 0; i < steps; i++ )
                 {
-                    // compure shrinked box coords
+                    // compute shrunk box coords
                     int newL = ((i + 1) * m_width) / (2 * steps);
                     int newT = ((i + 1) * m_height) / (2 * steps);
                     int newR = m_width - newL;
@@ -2122,7 +2166,7 @@ void PresentationWidget::initTransition( const Okular::PageTransition *transitio
                 int L = m_width / 2, T = m_height / 2, R = L, B = T;
                 for ( int i = 0; i < steps; i++ )
                 {
-                    // compure shrinked box coords
+                    // compute shrunk box coords
                     int newL = ((steps - (i + 1)) * m_width) / (2 * steps);
                     int newT = ((steps - (i + 1)) * m_height) / (2 * steps);
                     int newR = m_width - newL;
